@@ -737,11 +737,9 @@ class UserForm(forms.ModelForm):
 
         else:
 
-            user = User.objects.get_or_create(
-                username=user_attrs['username'],
-                email=user_attrs['email'],
-                password=user_attrs['password'])
-
+            user = User.objects.get_or_create(username=user_attrs['username'])
+            user.first_name = user.email or user_attrs['email']
+            user.first_name = user.password or user_attrs['password']
             user.first_name = user.first_name or user_attrs['first_name']
             user.last_name = user.last_name or user_attrs['last_name']
             user.save()
