@@ -404,6 +404,10 @@ def md5_gs(value, arg=None):
 def multiply(value, arg):
     return Decimal(str(value)) * Decimal(str(arg))
 
+@register.filter
+def add_decimal(value, arg):
+    return Decimal(str(value)) + Decimal(str(arg))
+
 @register.filter
 def phonenumber(value):
     if value:
